@@ -396,7 +396,10 @@ class VarDataFactory:
 
         # Infer stats tests (mingled with)
         tests = synthesize_tests(dataset, assumptions, combined_data)
-
+        
+        if dataset.data.empty:
+            print("Statistical Tests for empty dataset")
+            return tests
         """"
         # verify_properties(properties_and_tests)
         # get_tests
@@ -419,15 +422,27 @@ class VarDataFactory:
                 print(property_identifier)
         """
 
+        # Else
         # Execute and store results from each valid test
         results = {}
         if len(tests) == 0:
             tests.append('bootstrap')  # Default to bootstrap
 
+        
+        # Check to see if there is data on which to execute the synthesized tests
+        if dataset.has_empty_data():
+            return results
+
+        test_objs = ()
+
         for test in tests:
             test_result = execute_test(dataset, design, expr.predictions, combined_data, test)
             results[test] = test_result
 
+        for obj in test_objs:
+            obj.execute()
+            obj.visualize()
+
         res_data = ResultData(results, combined_data)
 
         follow_up = []
